--/Example 07

--/ Example of using the WHERE command to restrict record/row data during data retrieval from a table

SELECT 	OrderID, CustomerID, EmployeeID, 
	CONVERT(VARCHAR(10), OrderDate, 103) AS OrderDateAsString,
	CONVERT(VARCHAR(10), RequiredDate, 103) AS RequiredDateAsString, 
	CONVERT(VARCHAR(10), ShippedDate, 103) AS ShippedDateAsString,
	ShipVia, Freight, ShipName, 
	ShipAddress, ShipCity, ShipRegion, ShipPostalCode, ShipCountry
FROM orders
WHERE 	EmployeeID = 5

--/ Naturally this retrieves only those sales orders recorded by employee with EmployeeID = 5
--/ The WHERE command can be obviously far more complex and can use logical operators and functions to narrow down
--/ on the data retrieved in the result set

SELECT 	OrderID, CustomerID, EmployeeID, 
	CONVERT(VARCHAR(10), OrderDate, 103) AS OrderDateAsString,
	CONVERT(VARCHAR(10), RequiredDate, 103) AS RequiredDateAsString, 
	CONVERT(VARCHAR(10), ShippedDate, 103) AS ShippedDateAsString,
	ShipVia, Freight, ShipName, 
	ShipAddress, ShipCity, ShipRegion, ShipPostalCode, ShipCountry
FROM orders
WHERE 	EmployeeID = 5 OR
	EmployeeID = 6

--/ In the following example we are retrieving data using criteria from 2 fields combined with a logical AND
--/ Note the use of the CAST command to convert a 'string date' to a datetime
SELECT 	OrderID, CustomerID, EmployeeID, 
	CONVERT(VARCHAR(10), OrderDate, 103) AS OrderDateAsString,
	CONVERT(VARCHAR(10), RequiredDate, 103) AS RequiredDateAsString, 
	CONVERT(VARCHAR(10), ShippedDate, 103) AS ShippedDateAsString,
	ShipVia, Freight, ShipName, 
	ShipAddress, ShipCity, ShipRegion, ShipPostalCode, ShipCountry
FROM orders
WHERE 	EmployeeID = 5 AND
	OrderDate > CAST('01/01/1997' AS DATETIME)

--/ In this example we add the LIKE command, complete with wildcard character %, to retrieve records with
--/ data matched through a substring type function
--/ Note also that the fields used in a WHERE clause do NOT have to appear in the output result set
--/ and in the example below both EmployeeID and OrderDate fields have been removed. You just have to trust me
--/ that the query works!

SELECT 	OrderID, CustomerID,  
	CONVERT(VARCHAR(10), RequiredDate, 103) AS RequiredDateAsString, 
	CONVERT(VARCHAR(10), ShippedDate, 103) AS ShippedDateAsString,
	ShipVia, Freight, ShipName, 
	ShipAddress, ShipCity, ShipRegion, ShipPostalCode, ShipCountry
FROM orders
WHERE 	EmployeeID = 5 AND
	OrderDate > CAST('01/01/1997' AS DATETIME) AND
	ShipName LIKE '%markets%'

